==> smsmobileapi_send_email-0.1.0.tar.gz: smsmobileapi_send_email-0.1.0/README.md <==
# 📧 SMSMobileAPI Send Email

A Python module to send emails using [SMSMobileAPI](https://smsmobileapi.com/email/) after linking your email account to the API.

## 🌐 Service Overview
- Learn more about the service: [SMSMobileAPI Email](https://smsmobileapi.com/email/)
- Full documentation: [API Documentation](https://smsmobileapi.com/doc-email/)
- Don't have an account? [Sign up here](https://smsmobileapi.com/signup/?source_page=email)
- Already have an account? [Login to SMSMobileAPI Dashboard](https://smsmobileapi.com/connect)

## 🔑 Getting Started

### 1️⃣ **Create an Account & Configure Your Email**
Once logged into the **SMSMobileAPI Dashboard**, navigate to: MailBox -> MailConfig

Here, you can manage your connected email accounts and configure your email API settings.

### 2️⃣  **Generate Your API Keys**
- **Primary API Key** → Linked to your SMSMobileAPI account
- **Email API Key** → Linked to your connected email account

Once your SMTP credentials are saved, an **Email API Key** will be generated for your email. Use both API keys to authenticate and send emails via Python.

## 📦 Installation

```sh
pip install smsmobileapi-send-email

```

## 📧 SMSMobileAPI Send Email

from smsmobileapi_send_email import SMSMobileAPIEmailSender

apikey = "your_account_api_key"
apikeybox = "your_email_api_key"

sender = SMSMobileAPIEmailSender(apikey, apikeybox)

response = sender.send_email(
    sender_name="John Doe",
    sender_email="john.doe@example.com",
    recipient_email="recipient@example.com",
    mail_subject="Test Email",
    mail_body="Hello, this is a test email!",
    allow_self_signed="yes"
)

print(response)


## 🔒 Why Use SMSMobileAPI for Sending Emails?
1) Secure Email Sending – No need to store plaintext passwords in your Python scripts.
2) Email Tracking – All sent emails are visible in the SMSMobileAPI dashboard with detailed logs.
3) Easy Maintenance – If you change your email password, update it in the dashboard, not in your script.
4) Response Handling – The API returns a response indicating whether the email was successfully sent.

## 📝 License
This module is licensed under the MIT License.

==> smsmobileapi_send_email-0.3.2.tar.gz: smsmobileapi_send_email-0.3.2/README.md <==
# 📧 SMSMobileAPI Send Email

A Python module to send emails using [SMSMobileAPI](https://smsmobileapi.com/email/) after linking your email account to the API.

## 🌐 Service Overview
- Learn more about the service: [SMSMobileAPI Email](https://smsmobileapi.com/email/)
- Full documentation: [API Documentation](https://smsmobileapi.com/doc-email/)
- Don't have an account? [Sign up here](https://smsmobileapi.com/signup/?source_page=email)
- Already have an account? [Login to SMSMobileAPI Dashboard](https://smsmobileapi.com/connect)

## 🔑 Getting Started

### 1️⃣ **Create an Account & Configure Your Email**
Once logged into the **SMSMobileAPI Dashboard**, navigate to: MailBox -> MailConfig

Here, you can manage your connected email accounts and configure your email API settings.

### 2️⃣  **Generate Your API Keys**
- **Primary API Key** → Linked to your SMSMobileAPI account
- **Email API Key** → Linked to your connected email account

Once your SMTP credentials are saved, an **Email API Key** will be generated for your email. Use both API keys to authenticate and send emails via Python.

## 📦 Installation

```sh
pip install smsmobileapi-send-email

```

## 📧 SMSMobileAPI Send Email - Example

```python
from smsmobileapi_send_email import SMSMobileAPIEmailSender

apikey = "your_account_api_key"
apikeybox = "your_email_api_key"

sender = SMSMobileAPIEmailSender(apikey, apikeybox)

response = sender.send_email(
    sender_name="John Doe",
    sender_email="john.doe@example.com",
    recipient_email="recipient@example.com",
    mail_subject="Test Email",
    mail_body="Hello, this is a test email!",
    allow_self_signed="yes"
)

print(response)
```


## 🔒 Why Use SMSMobileAPI for Sending Emails?
1) Secure Email Sending – No need to store plaintext passwords in your Python scripts.
2) Email Tracking – All sent emails are visible in the SMSMobileAPI dashboard with detailed logs.
3) Easy Maintenance – If you change your email password, update it in the dashboard, not in your script.
4) Response Handling – The API returns a response indicating whether the email was successfully sent.

## 📌 Changelog

### v0.1.0 - Initial Release (2025-02-28)
- First stable release of `smsmobileapi-send-email`
- Added support for sending emails via SMSMobileAPI
- Implemented authentication using API keys
- Support for:
  - HTML and plain text emails
  - CC recipients (up to 3)
  - Attachments (Base64)
  - Embedded images
  - Unsubscribe links

### v0.2.0 - (2025-02-28)
- Improved error handling
- Added logging for debugging
- Response formatting improvements
- More customization options for email settings




## 📝 License
This module is licensed under the MIT License.
